@@ -264,6 +264,8 @@ class Configuration(client.Configuration):
 
     def refresh_token(self):
         # Make request with 'grant_type'='refresh_token'
+        if "refresh_token" not in self.token:
+            raise InvalidGrantError("Unable to refresh")
         self.token = self.session.refresh_token(
             token_url=self.token_endpoint,
             client_id=self.client_id,
