@@ -30,19 +30,26 @@ from alchemite_apiclient.model.column_group_response_all_of import ColumnGroupRe
 from alchemite_apiclient.model.column_info import ColumnInfo
 from alchemite_apiclient.model.column_value import ColumnValue
 from alchemite_apiclient.model.column_value_nullable import ColumnValueNullable
+from alchemite_apiclient.model.consistent_optimization_job import ConsistentOptimizationJob
 from alchemite_apiclient.model.continuous_column_info import ContinuousColumnInfo
 from alchemite_apiclient.model.continuous_column_info_all_of import ContinuousColumnInfoAllOf
 from alchemite_apiclient.model.continuous_column_info_stats import ContinuousColumnInfoStats
 from alchemite_apiclient.model.continuous_model_column_info import ContinuousModelColumnInfo
 from alchemite_apiclient.model.continuous_model_column_info_all_of import ContinuousModelColumnInfoAllOf
+from alchemite_apiclient.model.dr_auto_umap_reduction_type import DRAutoUMAPReductionType
+from alchemite_apiclient.model.dr_cluster_divergence import DRClusterDivergence
+from alchemite_apiclient.model.dr_data_types import DRDataTypes
 from alchemite_apiclient.model.dr_dataset_reduction_data import DRDatasetReductionData
+from alchemite_apiclient.model.dr_dataset_reduction_data_types import DRDatasetReductionDataTypes
 from alchemite_apiclient.model.dr_dataset_reduction_metadata import DRDatasetReductionMetadata
 from alchemite_apiclient.model.dr_dataset_reduction_metadata_sources import DRDatasetReductionMetadataSources
 from alchemite_apiclient.model.dr_job_reduction_metadata import DRJobReductionMetadata
 from alchemite_apiclient.model.dr_job_reduction_metadata_sources import DRJobReductionMetadataSources
 from alchemite_apiclient.model.dr_model_reduction_data import DRModelReductionData
+from alchemite_apiclient.model.dr_model_reduction_data_types import DRModelReductionDataTypes
 from alchemite_apiclient.model.dr_one_dimension_point import DROneDimensionPoint
 from alchemite_apiclient.model.drpca_reduction_type import DRPCAReductionType
+from alchemite_apiclient.model.dr_reduction_metadata import DRReductionMetadata
 from alchemite_apiclient.model.dr_three_dimension_point import DRThreeDimensionPoint
 from alchemite_apiclient.model.dr_two_dimension_point import DRTwoDimensionPoint
 from alchemite_apiclient.model.drumap_reduction_type import DRUMAPReductionType
@@ -78,15 +85,22 @@ from alchemite_apiclient.model.dimensionality_reduction_response import Dimensio
 from alchemite_apiclient.model.empty_categorical_column import EmptyCategoricalColumn
 from alchemite_apiclient.model.empty_continuous_column import EmptyContinuousColumn
 from alchemite_apiclient.model.error import Error
+from alchemite_apiclient.model.favourite_dataset import FavouriteDataset
+from alchemite_apiclient.model.favourite_job import FavouriteJob
+from alchemite_apiclient.model.favourite_patch import FavouritePatch
 from alchemite_apiclient.model.get_all_opt_jobs import GetAllOptJobs
 from alchemite_apiclient.model.get_optimize_done import GetOptimizeDone
 from alchemite_apiclient.model.get_optimize_done_all_of import GetOptimizeDoneAllOf
+from alchemite_apiclient.model.get_optimize_done_consistent import GetOptimizeDoneConsistent
 from alchemite_apiclient.model.get_optimize_failed import GetOptimizeFailed
 from alchemite_apiclient.model.get_optimize_failed_all_of import GetOptimizeFailedAllOf
+from alchemite_apiclient.model.get_optimize_failed_consistent import GetOptimizeFailedConsistent
 from alchemite_apiclient.model.get_optimize_optimizing import GetOptimizeOptimizing
 from alchemite_apiclient.model.get_optimize_optimizing_all_of import GetOptimizeOptimizingAllOf
+from alchemite_apiclient.model.get_optimize_optimizing_consistent import GetOptimizeOptimizingConsistent
 from alchemite_apiclient.model.get_optimize_pending import GetOptimizePending
 from alchemite_apiclient.model.get_optimize_pending_all_of import GetOptimizePendingAllOf
+from alchemite_apiclient.model.get_optimize_pending_consistent import GetOptimizePendingConsistent
 from alchemite_apiclient.model.get_suggest_additional_done import GetSuggestAdditionalDone
 from alchemite_apiclient.model.get_suggest_additional_done_all_of import GetSuggestAdditionalDoneAllOf
 from alchemite_apiclient.model.get_suggest_additional_failed import GetSuggestAdditionalFailed
@@ -126,11 +140,17 @@ from alchemite_apiclient.model.inline_response2003 import InlineResponse2003
 from alchemite_apiclient.model.inline_response2004 import InlineResponse2004
 from alchemite_apiclient.model.int_cat_arr import IntCatArr
 from alchemite_apiclient.model.job_patch import JobPatch
+from alchemite_apiclient.model.job_query import JobQuery
+from alchemite_apiclient.model.jobs_metadata_filters import JobsMetadataFilters
+from alchemite_apiclient.model.jobs_metadata_sort import JobsMetadataSort
 from alchemite_apiclient.model.load_request import LoadRequest
 from alchemite_apiclient.model.max import Max
 from alchemite_apiclient.model.metadata_optimization_job import MetadataOptimizationJob
+from alchemite_apiclient.model.metadata_optimization_job_all_of import MetadataOptimizationJobAllOf
 from alchemite_apiclient.model.metadata_suggest_additional_job import MetadataSuggestAdditionalJob
+from alchemite_apiclient.model.metadata_suggest_additional_job_all_of import MetadataSuggestAdditionalJobAllOf
 from alchemite_apiclient.model.metadata_suggest_historic_job import MetadataSuggestHistoricJob
+from alchemite_apiclient.model.metadata_suggest_historic_job_all_of import MetadataSuggestHistoricJobAllOf
 from alchemite_apiclient.model.min import Min
 from alchemite_apiclient.model.model import Model
 from alchemite_apiclient.model.model_column_info import ModelColumnInfo
@@ -179,7 +199,9 @@ from alchemite_apiclient.model.ot_sample_def_continuous import OTSampleDefContin
 from alchemite_apiclient.model.ot_sample_definition import OTSampleDefinition
 from alchemite_apiclient.model.ot_set_inputs import OTSetInputs
 from alchemite_apiclient.model.optimization_job import OptimizationJob
+from alchemite_apiclient.model.optimize_parameters import OptimizeParameters
 from alchemite_apiclient.model.optimize_request import OptimizeRequest
+from alchemite_apiclient.model.optimize_request_all_of import OptimizeRequestAllOf
 from alchemite_apiclient.model.outliers_request import OutliersRequest
 from alchemite_apiclient.model.output_tolerance_request import OutputToleranceRequest
 from alchemite_apiclient.model.output_tolerance_response import OutputToleranceResponse
@@ -190,6 +212,7 @@ from alchemite_apiclient.model.output_tolerance_response_sampled_inputs import O
 from alchemite_apiclient.model.output_tolerance_univariate_response import OutputToleranceUnivariateResponse
 from alchemite_apiclient.model.part_dependent_columns import PartDependentColumns
 from alchemite_apiclient.model.part_get_optimize import PartGetOptimize
+from alchemite_apiclient.model.part_get_optimize_consistent import PartGetOptimizeConsistent
 from alchemite_apiclient.model.part_get_optimize_done_result_array import PartGetOptimizeDoneResultArray
 from alchemite_apiclient.model.part_get_suggest_additional import PartGetSuggestAdditional
 from alchemite_apiclient.model.part_get_suggest_historic import PartGetSuggestHistoric
@@ -234,11 +257,8 @@ from alchemite_apiclient.model.set_inputs import SetInputs
 from alchemite_apiclient.model.share_group import ShareGroup
 from alchemite_apiclient.model.string_cat_arr import StringCatArr
 from alchemite_apiclient.model.suggest_additional_job import SuggestAdditionalJob
-from alchemite_apiclient.model.suggest_additional_metadata_filters import SuggestAdditionalMetadataFilters
-from alchemite_apiclient.model.suggest_additional_metadata_sort import SuggestAdditionalMetadataSort
 from alchemite_apiclient.model.suggest_additional_parameters import SuggestAdditionalParameters
 from alchemite_apiclient.model.suggest_additional_parameters_all_of import SuggestAdditionalParametersAllOf
-from alchemite_apiclient.model.suggest_additional_query import SuggestAdditionalQuery
 from alchemite_apiclient.model.suggest_additional_request import SuggestAdditionalRequest
 from alchemite_apiclient.model.suggest_additional_request_all_of import SuggestAdditionalRequestAllOf
 from alchemite_apiclient.model.suggest_additional_result import SuggestAdditionalResult
@@ -273,6 +293,8 @@ from alchemite_apiclient.model.tar_fn_exclude_categories import TarFnExcludeCate
 from alchemite_apiclient.model.tar_fn_exclude_categories_all_of import TarFnExcludeCategoriesAllOf
 from alchemite_apiclient.model.tar_fn_include_categories import TarFnIncludeCategories
 from alchemite_apiclient.model.tar_fn_include_categories_all_of import TarFnIncludeCategoriesAllOf
+from alchemite_apiclient.model.tar_fn_min_max import TarFnMinMax
+from alchemite_apiclient.model.tar_fn_min_max_all_of import TarFnMinMaxAllOf
 from alchemite_apiclient.model.tar_fn_sum_above import TarFnSumAbove
 from alchemite_apiclient.model.tar_fn_sum_above_all_of import TarFnSumAboveAllOf
 from alchemite_apiclient.model.tar_fn_sum_below import TarFnSumBelow
