@@ -2,12 +2,15 @@ from __future__ import print_function
 
 import csv
 import json
+import time
 from io import StringIO
 
-import alchemite_apiclient as client
 import matplotlib.pyplot as plt
-from alchemite_apiclient.extensions import (Configuration, await_job,
-                                            await_trained)
+import numpy as np
+import pandas as pd
+
+import alchemite_apiclient as client
+from alchemite_apiclient.extensions import Configuration, await_job, await_trained
 
 configuration = Configuration()
 api_default = client.DefaultApi(client.ApiClient(configuration))
@@ -32,7 +35,9 @@ model_name = "steels"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
@@ -70,9 +75,7 @@ model_id = api_models.models_post(model=model)
 print("Created model record ID:", model_id)
 
 # Start training the model using default hyperparameters and no validation
-response = api_models.models_id_train_put(
-    model_id, train_request={}
-)
+response = api_models.models_id_train_put(model_id, train_request={})
 print("Train response:", response)
 
 # Wait until the model has finished training
@@ -93,6 +96,7 @@ suggest_additional_job_id = api_models.models_id_suggest_additional_post(
 )
 print("suggest_additional job ID:", suggest_additional_job_id)
 
+
 # Wait until the suggest_additional job has finished
 def get_suggest_additional_job_metadata():
     return api_models.models_id_suggest_additional_job_id_get(
@@ -115,11 +119,10 @@ with open(optimize_args, encoding="UTF-8") as f:
 optimize_job_id = api_models.models_id_optimize_post(model_id, **optimize_args)
 print("Optimize job ID:", optimize_job_id)
 
+
 # Wait until the optimize job has finished
 def get_optimize_job_metadata():
-    return api_models.models_id_optimize_job_id_get(
-        model_id, job_id=optimize_job_id
-    )
+    return api_models.models_id_optimize_job_id_get(model_id, job_id=optimize_job_id)
 
 
 optimize_job = await_job(get_optimize_job_metadata)
@@ -127,38 +130,106 @@ optimize_job = await_job(get_optimize_job_metadata)
 ############################################################################
 ### Reduce the dataset down to a visualisable amount of dimensions
 ############################################################################
-print("\n--- Dimensionality Reduduction ---\n")
+print("\n--- Dimensionality Reduction ---\n")
 
 reduction_data_types = ["dataset", "optimize", "suggest-additional"]
 colours = ["black", "green", "gold"]
 
-for reduction_data_type, colour in zip(reduction_data_types, colours):
-    # Build dimensionality reduction request
-    print(f"Reducing using {reduction_data_type}...")
-    dimensionality_reduction_request = {
-        "reductionData": {
-            "modelID": model_id,
-            "reductionDataType": reduction_data_type,
-            "columnType": "all columns",
-        },
-        "reductionMethod": {
-            "method": "UMAP",
-            "dimensions": 2,
-            "numNeighbours": 5,
-            "minimumDistance": 0.5,
-        },
-    }
+# Example request for a single datatype
+
+dimensionality_reduction_request = {
+    "reductionData": {
+        "modelID": model_id,
+        "reductionDataType": "dataset",
+        "columnType": "all columns",
+    },
+    "reductionMethod": {
+        "method": "UMAP",
+        "dimensions": 2,
+        "numNeighbours": 5,
+        "minimumDistance": 0.5,
+    },
+}
+# Example requesting all reduction datatypes
+
+dimensionality_reduction_request = {
+    "reductionData": {
+        "modelID": model_id,
+        "reductionDataTypes": reduction_data_types,
+        "columnType": "all columns",
+    },
+    "reductionMethod": {
+        "method": "UMAP",
+        "dimensions": 2,
+        "numNeighbours": 5,
+        "minimumDistance": 0.5,
+    },
+}
+
+
+print("Reducing all dimensionality reduction types based on Auto UMAP:")
+
+dimensionality_reduction_request = {
+    "reductionData": {
+        "modelID": model_id,
+        "reductionDataTypes": reduction_data_types,
+        "columnType": "all columns",
+    },
+    "reductionMethod": {
+        "method": "Auto UMAP",
+    },
+}
+
+dimensionality_reduction_response = (
+    api_datasets.datasets_id_dimensionality_reduction_put(
+        dataset_id,
+        dimensionality_reduction_request=dimensionality_reduction_request,
+    )
+)
+while dimensionality_reduction_response is None:
+    time.sleep(1)
     dimensionality_reduction_response = (
         api_datasets.datasets_id_dimensionality_reduction_put(
             dataset_id,
             dimensionality_reduction_request=dimensionality_reduction_request,
         )
     )
-    # Plot the points
-    plot_points = dimensionality_reduction_response.reduction_coordinates
-    x = plot_points["x"]
-    y = plot_points["y"]
-    metadata = dimensionality_reduction_response.reduction_metadata
-    plt.scatter(x, y, color=colour)
 
+# Get points from response
+plot_points = dimensionality_reduction_response.reduction_coordinates
+x = np.array(plot_points["x"])
+y = np.array(plot_points["y"])
+clusters = np.array(plot_points["cluster"])
+metadata = dimensionality_reduction_response.reduction_metadata
+
+# Plot the points by data type (dataset, suggest-additional, optimize)
+for reduction_data_type, colour in zip(reduction_data_types, colours):
+    source_indices = [
+        i
+        for i, data_source in enumerate(metadata["sources"])
+        if data_source["dataType"] == reduction_data_type
+    ]
+    plot_x = x[source_indices]
+    plot_y = y[source_indices]
+    plt.scatter(plot_x, plot_y, color=colour, label=reduction_data_type)
+
+plt.legend()
 plt.show()
+
+# Plot all points and colour by cluster
+# Do not plot any None clusters
+unique_clusters = set(clusters) - {None}
+for cluster in sorted(unique_clusters):
+    cluster_mask = clusters == cluster
+    cluster_x = x[cluster_mask]
+    cluster_y = y[cluster_mask]
+    plt.scatter(cluster_x, cluster_y, label=f"Cluster {cluster}")
+
+plt.legend()
+plt.show()
+
+# Print Divergence matrix for each cluster that is not None
+divergence = pd.DataFrame.from_records(plot_points["clusterDivergence"])
+# Columns are dataset columns
+# Cluster label is index
+print(divergence)
